function validateisNotNull(val) {
	var reg = /^\s*$/g;
	return reg.test(val);
}

function validatePhone(val) {
	var regPhone = /^1(3|4|5|6|7|8)\d{9}$/;
	if (!regPhone.test(val)) {
		return true;
	}
	return false;
}

function focus(id){
	$("#"+id+"").focus();
}

function validateNameLength(val) {
	var _reg = /^\S{1,14}$/;
	if (!_reg.test(visitorName)) {
		return false;
	}
	return true;
}

function showMessage(desc) {
	layer.open({
		content : desc,
		skin : 'msg',
		time : 2
	// 2秒后自动关闭
	});
}

function showLoading(desc){
	layer.open({
	    type: 2
	    ,content:desc
	  });
}

function closeLayer(){
	layer.closeAll();
}
